import { RegistryAccess } from '../registry/registryAccess';
import { ComponentSet } from '../collections';
import { SourceComponent } from './sourceComponent';
import { TreeContainer } from './treeContainers';
/**
 * Resolver for metadata type and component objects.
 *
 * @internal
 */
export declare class MetadataResolver {
    private registry;
    private tree;
    private useFsForceIgnore;
    forceIgnoredPaths: Set<string>;
    private forceIgnore;
    private sourceAdapterFactory;
    private folderContentTypeDirNames;
    /**
     * @param registry Custom registry data
     * @param tree `TreeContainer` to traverse with
     */
    constructor(registry?: RegistryAccess, tree?: TreeContainer, useFsForceIgnore?: boolean);
    /**
     * Get the metadata component(s) from a file path.
     *
     * @param fsPath File path to metadata or directory
     * @param inclusiveFilter Set to filter which components are resolved
     */
    getComponentsFromPath(fsPath: string, inclusiveFilter?: ComponentSet): SourceComponent[];
    private getComponentsFromPathRecursive;
    private resolveComponent;
    /**
     * Any metadata xml file (-meta.xml) is potentially a root metadata file.
     *
     * @param fsPath File path of a potential metadata xml file
     */
    private parseAsRootMetadataXml;
    private resolveTypeFromStrictFolder;
    private resolveType;
    /**
     * Whether or not a directory that represents a single component should be resolved as one,
     * or if it should be walked for additional components.
     *
     * If a type can be determined from a directory path, and the end part of the path isn't
     * the directoryName of the type itself, infer the path is part of a mixedContent component
     *
     * @param dirPath Path to a directory
     */
    private resolveDirectoryAsComponent;
    /**
     * Any file with a registered suffix is potentially a content metadata file.
     *
     * @param fsPath File path of a potential content metadata file
     */
    private parseAsContentMetadataXml;
    private getFolderContentTypeDirNames;
    /**
     * Identify metadata xml for a folder component:
     * .../email/TestFolder-meta.xml
     * .../reports/foo/bar-meta.xml
     *
     * Do not match this pattern:
     * .../tabs/TestFolder.tab-meta.xml
     */
    private parseAsFolderMetadataXml;
    private isMetadata;
}
